#include <debug.h>
#include <makros.h>
#include <RCReceive.h>
#include <SoftwareServo.h>

/*
 Steuerung eines Flug ESC mittels Car Fernsteuerng für den ATTiny 84. 
 Der Empfänger wird vom Pin 2 gelesen, 
 die Ausgänge sind auf PA4/5 was in arduino Pin 6/5 entspricht.
 Die Nullpunkte des Kanal wird automatisch beim Start ermittelt.
 Die Steuerung erfolgt folgendermaßen: Bei Vorwärtsfahrt wird das Motorsignal ohne 
 Änderung direkt an den Regler geschickt. 
  */
const byte PIN_RC = 2;

// Ausgänge
const byte ESC = 0;

RCReceive rcReceive;

SoftwareServo myEsc;

void setup() {
  // Kanäle auf Ausgang, und dann deaktivieren
  myEsc.attach(ESC);
  myEsc.write(0);

  rcReceive.attach(PIN_RC);
}

void loop() {
  myEsc.refresh();

  // Aktuellen RC-Wert lesen
  rcReceive.poll();

  if (rcReceive.hasNP()) {
    if (!rcReceive.hasError()) {
      int rcValue = rcReceive.getMsValue();
      if (rcValue > rcReceive.getNP()+3) {
        // Vorwärts fahren, hier wird der Wert des Carsenders auf den Bereich des ESC gemappt.
        rcValue = map(rcValue, rcReceive.getNP(), 2000, 0, 180);
        myEsc.write(rcValue);
      } 
      else {
        // bei Rückwärts einfach ausschalten
        myEsc.write(0);
    }}
  } 
  else {
    // Fehlerfall failsafe ...
    myEsc.write(0);
  }
}

